﻿/*!
*  filename: Orubase-1.0.0.js
*  Copyright Syncfusion Inc. 2001 - 2012. All rights reserved.
*  Use of this code is subject to the terms of our license.
*  A copy of the current license can be obtained at any time by e-mailing
*  licensing@syncfusion.com. Any infringement will be prosecuted under
*  applicable laws. 
*/

//Global variables used in the file, "Android" is name of interface used to communicate with Android devices.
/*global Android,document,navigator,window*/

//namespace
var Orubase = {};

//Define the type of devices
var OrubaseEnums = {
    DEVICENAMES: {
        ANDROID: 'android',
        IPHONE: 'iphone',
        IPOD: 'ipod',
        IPAD: 'ipad',
        WINDOWS_PHONE: 'windows_phone',
        OTHER_DEVICE: 'other_device'
    },
    ENCRYPTIONMODES:
	{
	    NONE: 'none',
	    AES: 'aes',
	    CUSTOM: 'custom'
	},
    FILEWRITEMODES:
	{
	    NONE: 'none',
	    APPEND: 'append',
	    OVERWRITE: 'overwrite'
	}
};

// An Utility function for Orubase
Orubase.Utility = (function () {

    //variable for getting the device name
    this.DeviceName = null;
    var self = {
        //to check the type of device
        getDeviceName: function () {
            var useragent = navigator.userAgent.toLowerCase();

            if (useragent.indexOf("ipod") > -1) {
                this.DeviceName = OrubaseEnums.DEVICENAMES.IPOD;
            } else if (useragent.indexOf("iphone") > -1) {
                this.DeviceName = OrubaseEnums.DEVICENAMES.IPHONE;
            } else if (useragent.indexOf("ipad") > -1) {
                this.DeviceName = OrubaseEnums.DEVICENAMES.IPAD;
            } else if (useragent.indexOf("android") > -1) {
                this.DeviceName = OrubaseEnums.DEVICENAMES.ANDROID;
            } else if (useragent.indexOf("windows phone") > -1) {
                this.DeviceName = OrubaseEnums.DEVICENAMES.WINDOWS_PHONE;
            } else {
                this.DeviceName = OrubaseEnums.DEVICENAMES.OTHER_DEVICE;
            }
            return this.DeviceName;
        },

        //to check whether the device is iOS type
        isIOSDevice: function () {
            return this.DeviceName === OrubaseEnums.DEVICENAMES.IPHONE || this.DeviceName === OrubaseEnums.DEVICENAMES.IPAD || this.DeviceName === OrubaseEnums.DEVICENAMES.IPOD;
        },

        // to cleanup the global variable
        cleanup: function (callback) {
            delete window[callback];
        },

        //will perform the call for briging the webpage request to native app code
        PerformCall: function (api, callback, arryargs) {
            var scriptname = "SF_" + api, args = "", i = 0, result;
            if (callback === null) { callback = "nocallback"; }
            // bridge code for Windows Phone devices
            if (this.DeviceName === OrubaseEnums.DEVICENAMES.WINDOWS_PHONE) {
                if (arryargs !== null) {
                    for (i = 0; i < arryargs.length; i = i + 1) {
                        args = args + arryargs[i] + "*****";
                    }
                }
                result = "scriptname$$$$$" + scriptname + " callback$$$$$" + callback + " args$$$$$" + args;
                window.external.notify(result);
            }
            // bridge code for Android devices
            if (this.DeviceName === OrubaseEnums.DEVICENAMES.ANDROID) {
                Android.ProcessJavaScript(scriptname, callback, arryargs);
            }
            // bridge code for iOS devices
            if (Orubase.Utility.isIOSDevice()) {
                args = callback + "$$$$$";
                if (arryargs !== null) {
                    for (i = 0; i < arryargs.length; i = i + 1) {
                        args = args + arryargs[i] + "$$$$$";
                    }
                }
                document.location = "iphone:" + "SF_" + api + "$$$$$" + args + "data";
            }
        }
    };
    return self;
} ());

// Orubase Contacts class - for accessing, adding and searching the contacts of the device
Orubase.Contacts = (function () {
    "use strict";
    //Temp variables, for contacts callback
    var callbackNameGetContacts = "SF_CallbackGetContacts", callbackNameAddContacts = "SF_CallbackAddContacts", callbackNameSearchContacts = "SF_CallbackSearchContacts", self;
    self = {
        //user call for getting the contacts of the device.
        //Handler for user to get the contacts results returned from the device.
        getContacts: function (p) {
            window[callbackNameGetContacts] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameGetContacts);
            };
            Orubase.Utility.PerformCall("GetContacts", callbackNameGetContacts, null);
        },

        //user call for adding the contacts, need to pass firstname, lastname, email, phone number.
        //Handler for user to check whether given contact information saved in the device or not.
        addContacts: function (firstname, lastname, email, phone, p) {
            window[callbackNameAddContacts] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameAddContacts);
            };
            var args = [firstname, lastname, email, phone];
            Orubase.Utility.PerformCall("AddContact", callbackNameAddContacts, args);
        },

        //user call for searching the contacts by firstname of person
        searchByFirstName: function (name, p) {
            window[callbackNameSearchContacts] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameSearchContacts);
            };
            var args = [name];
            Orubase.Utility.PerformCall("SearchByFName", callbackNameSearchContacts, args);
        },

        //user call for searching the contacts by lastname of person
        searchByLastName: function (name, p) {
            window[callbackNameSearchContacts] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameSearchContacts);
            };
            var args = [name];
            Orubase.Utility.PerformCall("SearchByLName", callbackNameSearchContacts, args);
        },

        //user call for searching the contacts by email  id of person
        searchByNumber: function (no, p) {
            window[callbackNameSearchContacts] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameSearchContacts);
            };
            var args = [no];
            Orubase.Utility.PerformCall("SearchByNumber", callbackNameSearchContacts, args);
        },

        //user call for searching the contacts by phone number of person
        searchByMail: function (mailid, p) {
            window[callbackNameSearchContacts] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameSearchContacts);
            };
            var args = [mailid];
            Orubase.Utility.PerformCall("SearchByMail", callbackNameSearchContacts, args);
        }
    };
    return self;
} ());

// Orubase Location class - for getting the current Geo Location of the device
Orubase.Location = (function () {
    "use strict";
    //Temp variable, for getting location callback 
    var callbackName = "SF_CallbackGetLocation", self;
    self = {
        //user call for getting the geo location of the device.
        //handler for user to get the geo location details of the device
        getLocation: function (p) {
            window[callbackName] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
            };
            Orubase.Utility.PerformCall("GetGeoLocation", callbackName, null);
        }
    };
    return self;
} ());

// Orubase Storage class - for accessing the Database of the device
Orubase.SQLiteStorage = (function () {

    "use strict";
    var callbackNameExecuteNonQuery = "SF_CallbackExecuteNonQuery", callbackNameExecuteQuery = "SF_CallbackExecuteQuery";
    var callbackNamecreateDatabase = "SF_CallBackCreateDatabase", self;
    var callbackNameSelectAll = "SF_CallbackSelectAll", callbackNameDeleteTable = "SF_CallbackDeleteTable";
    var callbackNameDeleteAllRecords = "SF_CallbackDeleteAllRecords", callbackNameDeleteTables = "SF_CallbackDeleteTables";

    self = {

        createDatabase: function (name, p) {
            window[callbackNamecreateDatabase] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
            };
            var args = [name];
            Orubase.Utility.PerformCall("CreateDatabase", callbackNamecreateDatabase, args);
        },

        executeNonQuery: function (query, p) {
            window[callbackNameExecuteNonQuery] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
            };
            var args = [query];
            Orubase.Utility.PerformCall("ExecuteSQLiteNonQuery", callbackNameExecuteNonQuery, args);
        },

        executeQuery: function (query, p) {
            window[callbackNameExecuteQuery] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
            };
            var args = [query];
            Orubase.Utility.PerformCall("ExecuteSQLiteQuery", callbackNameExecuteQuery, args);
        },
        selectAll: function (tablename, p) {
            window[callbackNameSelectAll] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
            };
            var args = [tablename];
            Orubase.Utility.PerformCall("SelectAll", callbackNameSelectAll, args);
        },
        deleteAllTables: function (databaseName, p) {
            window[callbackNameDeleteTables] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
            };
            var args = [databaseName];
            Orubase.Utility.PerformCall("DeleteAllTables", callbackNameDeleteTables, args);
        },
        deleteAllRecords: function (tablename, p) {
            window[callbackNameDeleteAllRecords] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
            };
            var args = [tablename];
            Orubase.Utility.PerformCall("DeleteAllRecords", callbackNameDeleteAllRecords, args);
        },
        deleteTable: function (tablename, p) {
            window[callbackNameDeleteTable] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
            };
            var args = [tablename];
            Orubase.Utility.PerformCall("DeleteTable", callbackNameDeleteTable, args);
        }
    };
    return self;
} ());


// Orubase Accelerometer Class - to monitor the device movement in X,Y,Z directions
Orubase.Accelerometer = (function () {
    "use strict";
    //Temp variable, for getting Accelerometer callback
    var callbackNamegetAccelerometer = "SF_CallbackGetAccelerometer", self;
    self = {
        //user call for getting the Accelerometer readings of the device.
        //handler for user to get the Accelerometer readings of the device.
        getAccelerometer: function (p) {
            window[callbackNamegetAccelerometer] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
            };
            Orubase.Utility.PerformCall("GetAccelerometer", callbackNamegetAccelerometer, null);
        },

        //user call to stop monitoring the Accelerometer readings of the device
        stopAccelerometer: function () {
            Orubase.Utility.PerformCall("StopAccelerometer", null, null);
            Orubase.Utility.cleanup(callbackNamegetAccelerometer);
        }
    };
    return self;
} ());

//Orubase Notification class - for invoking native notifications (alert, beep, vibarate)
Orubase.Notification = (function () {
    "use strict";
    //Temp variable, for getting notificaiton callback
    var callbackName = "SF_CallbackShowNotification", self;
    self = {
        //user call to invoke the native alert dialog of deivce with given alert title and message.
        //handler for user to get the response of native alert dialog invoked
        showNotifcation: function (alertmessage, alerttitle, p) {
            window[callbackName] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackName);
            };
            var args = [alertmessage, alerttitle];
            Orubase.Utility.PerformCall("GetNotification", callbackName, args);
        },

        // user call to play the beep sound in  the deivce
        beep: function (beepcount) {
            var args = [beepcount];
            Orubase.Utility.PerformCall("BeepNotification", null, args);
        },
        //user call to make the device vibrate for given duration
        vibrate: function (vibrateduration) {
            var args = [vibrateduration];
            Orubase.Utility.PerformCall("VibrateNotification", null, args);
        }
    };
    return self;
} ());

//Orubase Device class - for getting the device infomation (eg: device model, version)
Orubase.Device = (function () {
    "use strict";
    //Temp variable, for getting device information callback
    var callbackName = "SF_CallbackGetDeviceInformation", self;
    self = {
        //user call to get the information about the device.
        //handler for user to get the response of device information.
        getInformation: function (p) {
            window[callbackName] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackName);
            };
            Orubase.Utility.PerformCall("GetDeviceInformation", callbackName, null);
        }
    };
    return self;
} ());

//Orubase Media class - for accessing the media library of the device (images, audio and video)
Orubase.Media = (function () {
    "use strict";
    //Temp variables, for callbacks related to accessing the Media library of device
    var callbackNameChoosePhoto = "SF_CallbackChoosePhoto", callbackNameTakePhoto = "SF_CallbackTakePhoto", callbackNameCaptureImage = "SF_CallbackCaptureImage", callbackNameCaptureAudio = "SF_CallbackCaptureAudio", callbackNameCaptureVideo = "SF_CallbackCaptureVideo", self;
    self = {
        //user call to access the images stored in the device media library.
        //handler for user to get the information about the image choosed in the media libary of the device.
        choosePhoto: function (p) {
            window[callbackNameChoosePhoto] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameChoosePhoto);
            };
            Orubase.Utility.PerformCall("ShowPhoto", callbackNameChoosePhoto, null);
        },

        //user call to take photo by the device camera.
        //handler for user to get the information about the image taken via device camera.
        takePhoto: function (p) {
            window[callbackNameTakePhoto] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameTakePhoto);
            };
            Orubase.Utility.PerformCall("TakePhoto", callbackNameTakePhoto, null);
        },

        //user call to caputre photo by device camera.
        //handler for user to get the information about the image captured via device camera.
        captureImage: function (p) {
            window[callbackNameCaptureImage] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameCaptureImage);
            };
            Orubase.Utility.PerformCall("CaptureImage", callbackNameCaptureImage, null);
        },

        //user call to caputre audio by the device microphone.
        //handler for user to get the information about the audio captured via device microphone.
        captureAudio: function (p) {
            window[callbackNameCaptureAudio] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameCaptureAudio);
            };
            Orubase.Utility.PerformCall("CaptureAudio", callbackNameCaptureAudio, null);
        },

        //user call to caputre video by device camera.
        //handler for user to get the information about the video captured via device camera.
        CaptureVideo: function (p) {
            window[callbackNameCaptureVideo] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameCaptureVideo);
            };
            Orubase.Utility.PerformCall("CaptureVideo", callbackNameCaptureVideo, null);
        },

        //user call to play video in the device video player
        playVideo: function (path) {
            var args = [path];
            Orubase.Utility.PerformCall("PlayMedia", null, args);
        },
        //user call to play audio in the device audio player
        playAudio: function (path) {
            var args = [path];
            Orubase.Utility.PerformCall("PlayAudio", null, args);
        }
    };
    return self;
} ());

//Orubase IP class - for getting the IP of the device
Orubase.IP = (function () {
    //Temp variable for callback related to getting the IP address of the device
    "use strict";
    var callbackName = "SF_CallbackGetIPAddress", self;
    self = {
        //user call to get the IP address of the device.
        //handler for user to get the IP address of  the device.
        getAddress: function (p) {
            window[callbackName] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
            };
            Orubase.Utility.PerformCall("GetIPAddress", callbackName, null);
        }
    };
    return self;
} ());

//Orubase Network class - for getting the type of network connected by  the device
Orubase.Network = (function () {
    "use strict";
    //Temp variable for callback related to getting the Network info of  the device
    var callbackName = "SF_CallbackGetConnectionInfo", self;
    self = {
        //user call to get the network connection information of device.
        //handler for user to get information about network connection of the device
        getConnectionInfo: function (p) {
            window[callbackName] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackName);
            };
            Orubase.Utility.PerformCall("GetConnectionInformation", callbackName, null);
        }
    };
    return self;
} ());

//Orubase Compass class - for getting readings of compass sensor in  the device
Orubase.Compass = (function () {
    "use strict";
    //Temp variable for callback related to getting the reading of compass sensor
    var callbackName = "SF_CallbackGetCompass", self;
    self = {
        //user call to start monitoring the device compass sensor reading.
        //handler for user to get the device compass sensor reading.
        getValue: function (p) {
            window[callbackName] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    var result = JSON.parse(data);
                    p.onSuccess(result);
                } else {
                    p.onFailure(data);
                }
            };
            Orubase.Utility.PerformCall("GetCompass", callbackName, null);
        },
        //user call to stop monitoring the device compass sensor reading
        stop: function () {
            Orubase.Utility.PerformCall("StopCompass", null, null);
            Orubase.Utility.cleanup(callbackName);
        }
    };
    return self;
} ());

//Orubase storage class - for text file manipulation in  the device
Orubase.Storage = (function () {
    "use strict";
    //Temp variables for callbacks related to file manipulations in the device
    var callbackNameFileExists = "SF_CallbackisFileExists", callbackNameDirectoryExists = "SF_CallbackisDirectoryExists", callbackNameCreateFile = "SF_CallbackCreateFile", callbackNameCreateDirectory = "SF_CallbackCreateDirectory", callbackNameDeleteFile = "SF_CallbackDeleteFile", callbackNameDeleteDirectory = "SF_CallbackDeleteDirectory", callbackNameWriteFile = "SF_CallbackWriteFile", callbackNameReadFile = "SF_CallbackReadFile", self;
    self = {
        //user call to check whether the given file exists in  the device or not.
        //handler for user to check whether the given file exists in  the device or not.
        isFileExists: function (directoryname, filename, p) {
            window[callbackNameFileExists] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameFileExists);
            };
            var args = [directoryname, filename];
            Orubase.Utility.PerformCall("CheckFileExists", callbackNameFileExists, args);
        },
        //user call to check whether the given directory exists in  the device or not.
        //handler for user to check whether the given directory exists in  the device or not.
        isDirectoryExists: function (directoryname, p) {
            window[callbackNameDirectoryExists] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameDirectoryExists);
            };
            var args = [directoryname];
            Orubase.Utility.PerformCall("CheckDirExists", callbackNameDirectoryExists, args);
        },

        //user call to create the given file in  the device.
        //handler for user to check whether the given file created in the device or not.
        createFile: function (directoryname, filename, p) {
            window[callbackNameCreateFile] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameCreateFile);
            };
            var args = [directoryname, filename];
            Orubase.Utility.PerformCall("CreateFile", callbackNameCreateFile, args);
        },
        //user call to create the given directory in the  device.
        //handler for user to check whether the given directory created in the device or not.
        createDirectory: function (directoryname, p) {
            window[callbackNameCreateDirectory] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameCreateDirectory);
            };
            var args = [directoryname];
            Orubase.Utility.PerformCall("CreateDirectory", callbackNameCreateDirectory, args);
        },
        //user call to delete the given file in  the device.
        //handler for user to check whether the given file deleted from the device or not.
        deleteFile: function (directoryname, filename, p) {
            window[callbackNameDeleteFile] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameDeleteFile);
            };
            var args = [directoryname, filename];
            Orubase.Utility.PerformCall("DeleteFile", callbackNameDeleteFile, args);
        },
        //user call to create the given directory in  the device.
        //handler for user to check whether the given directory deleted from the device or not.
        deleteDirectory: function (directoryname, p) {
            window[callbackNameDeleteDirectory] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameDeleteDirectory);
            };
            var args = [directoryname];
            Orubase.Utility.PerformCall("DeleteDirectory", callbackNameDeleteDirectory, args);
        },
        //user call to write the given contents in specified file in  the device.
        //handler for user to check whether the contents written in the file or not.
        writeFile: function (directoryname, filename, content, writemode, encryptionmode, p) {
            window[callbackNameWriteFile] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameWriteFile);
            };
            var args = [directoryname, filename, content, writemode, encryptionmode];
            Orubase.Utility.PerformCall("WriteFile", callbackNameWriteFile, args);
        },
        //user call to read the contents of specified file in the  device.
        //handler for user to read the contents of file.
        readFile: function (directoryname, filename, encryptionmode, p) {
            window[callbackNameReadFile] = function (status, data) {
                if (status.toLowerCase() === "true") {
                    p.onSuccess(data);
                } else {
                    p.onFailure(data);
                }
                Orubase.Utility.cleanup(callbackNameReadFile);
            };
            var args = [directoryname, filename, encryptionmode];
            Orubase.Utility.PerformCall("ReadFile", callbackNameReadFile, args);
        }
    };
    return self;
} ());